@@ -1,9 +1,7 @@
 DEFAULT_EXTENSIONS = [
     "jinja2.ext.do",
     "jinja2.ext.loopcontrols",
-    "jinja2.ext.with_",
     "jinja2.ext.i18n",
-    "jinja2.ext.autoescape",
     "django_jinja.builtins.extensions.DebugExtension",
     "django_jinja.builtins.extensions.CsrfExtension",
     "django_jinja.builtins.extensions.CacheExtension",
