@@ -199,8 +199,7 @@ class RenderTemplatesTests(TestCase):
             template = self.env.from_string(template_content)
             result = template.render({}, request)
 
-            expected = ("<input type='hidden' name='csrfmiddlewaretoken'"
-                        " value='{}' />").format(token)
+            expected = f"<input type='hidden' name='csrfmiddlewaretoken' value='{token}' />"
 
         self.assertEqual(token, "123123")
         self.assertEqual(result, expected)
@@ -274,12 +273,12 @@ class RenderTemplatesTests(TestCase):
         }
 
         with self.modify_settings(TEMPLATES=setting):
-            with self.assertRaisesRegexp(ImproperlyConfigured, r'Several Jinja2 backends'):
+            with self.assertRaisesRegex(ImproperlyConfigured, r'Several Jinja2 backends'):
                 Jinja2.get_default()
 
     def test_get_default_none(self):
         with self.settings(TEMPLATES=global_settings.TEMPLATES):
-            with self.assertRaisesRegexp(ImproperlyConfigured, r'No Jinja2 backend is configured'):
+            with self.assertRaisesRegex(ImproperlyConfigured, r'No Jinja2 backend is configured'):
                 Jinja2.get_default()
 
 
@@ -321,35 +320,6 @@ class RenderTemplatesTests(TestCase):
         )
 
 
-class DjangoPipelineTestTest(TestCase):
-    def setUp(self):
-        self.env = engines["jinja2"]
-
-    def test_pipeline_js_safe(self):
-        template = self.env.from_string("{{ compressed_js('test') }}")
-        result = template.render({})
-
-        self.assertTrue(result.startswith("<script"))
-        self.assertIn("text/javascript", result)
-        self.assertIn("/static/script.2.js", result)
-
-    def test_pipeline_css_safe_01(self):
-        template = self.env.from_string("{{ compressed_css('test') }}")
-        result = template.render({})
-        self.assertIn("media=\"all\"", result)
-        self.assertIn("stylesheet", result)
-        self.assertIn("<link", result)
-        self.assertIn("/static/style.2.css", result)
-
-    def test_pipeline_css_safe_02(self):
-        template = self.env.from_string("{{ compressed_css('test2') }}")
-        result = template.render({})
-        self.assertNotIn("media", result)
-        self.assertIn("stylesheet", result)
-        self.assertIn("<link", result)
-        self.assertIn("/static/style.2.css", result)
-
-
 class BaseTests(TestCase):
     def setUp(self):
         self.env = engines["jinja2"]
@@ -367,7 +337,7 @@ class BaseTests(TestCase):
             match_template('admin/foo.html', regex=r"^(?!admin/.*)", extension=None))
 
     def test_get_match_extension(self):
-        self.assertEquals(Jinja2.get_default().match_extension, get_match_extension())
+        self.assertEqual(Jinja2.get_default().match_extension, get_match_extension())
 
     def test_get_match_extension_using(self):
         setting = {
@@ -384,12 +354,12 @@ class BaseTests(TestCase):
         }
 
         with self.modify_settings(TEMPLATES=setting):
-            self.assertEquals(".jinja", get_match_extension(using='jinja2'))
-            self.assertEquals(".jinjadup", get_match_extension(using="jinja2dup"))
+            self.assertEqual(".jinja", get_match_extension(using='jinja2'))
+            self.assertEqual(".jinjadup", get_match_extension(using="jinja2dup"))
 
 
 class TemplateResponseTests(TestCase):
-    class _BaseView(object):
+    class _BaseView:
         def get_template_names(self):
             return [
                 'name1.html',
@@ -405,7 +375,7 @@ class TemplateResponseTests(TestCase):
             pass
 
         view = _View()
-        self.assertEquals(
+        self.assertEqual(
             ['name1.html.jinja', 'name2.html.jinja', 'name3.html.jinja'],
             view.get_template_names()
         )
@@ -415,7 +385,7 @@ class TemplateResponseTests(TestCase):
             jinja2_template_extension = '.foo'
 
         view = _View()
-        self.assertEquals(
+        self.assertEqual(
             ['name1.html.foo', 'name2.html.foo', 'name3.html.jinja.foo'],
             view.get_template_names()
         )
@@ -439,7 +409,7 @@ class TemplateResponseTests(TestCase):
 
         with self.modify_settings(TEMPLATES=setting):
             view = _View()
-            self.assertEquals(
+            self.assertEqual(
                 ['name1.html.jinjadup', 'name2.html.jinjadup', 'name3.html.jinja.jinjadup'],
                 view.get_template_names()
             )
@@ -451,7 +421,7 @@ class GenericViewTests(TestCase):
 
     def test_detailview(self):
         self.assertContains(
-            self.client.get('/testmodel/{0}/detail'.format(self.obj1.pk)),
+            self.client.get(f'/testmodel/{self.obj1.pk}/detail'),
             'DetailView Test Template',
             status_code=200
         )
@@ -465,14 +435,14 @@ class GenericViewTests(TestCase):
 
     def test_deleteview(self):
         self.assertContains(
-            self.client.get('/testmodel/{0}/delete'.format(self.obj1.pk)),
+            self.client.get(f'/testmodel/{self.obj1.pk}/delete'),
             'DeleteView Test Template',
             status_code=200
         )
 
     def test_updateview(self):
         self.assertContains(
-            self.client.get('/testmodel/{0}/update'.format(self.obj1.pk)),
+            self.client.get(f'/testmodel/{self.obj1.pk}/update'),
             'UpdateView Test Template',
             status_code=200
         )
@@ -493,28 +463,28 @@ class GenericViewTests(TestCase):
 
     def test_yeararchiveview(self):
         self.assertContains(
-            self.client.get('/testmodel/archive/{0:%Y}/'.format(self.obj1.date)),
+            self.client.get(f'/testmodel/archive/{self.obj1.date:%Y}/'),
             'YearArchiveView Test Template',
             status_code=200
         )
 
     def test_montharchiveview(self):
         self.assertContains(
-            self.client.get('/testmodel/archive/{0:%Y/%b}/'.format(self.obj1.date)),
+            self.client.get(f'/testmodel/archive/{self.obj1.date:%Y/%b}/'),
             'MonthArchiveView Test Template',
             status_code=200
         )
 
     def test_weekarchiveview(self):
         self.assertContains(
-            self.client.get('/testmodel/archive/{0:%Y/week/%U}/'.format(self.obj1.date)),
+            self.client.get(f'/testmodel/archive/{self.obj1.date:%Y/week/%U}/'),
             'WeekArchiveView Test Template',
             status_code=200
         )
 
     def test_dayarchiveview(self):
         self.assertContains(
-            self.client.get('/testmodel/archive/{0:%Y/%b/%d}/'.format(self.obj1.date)),
+            self.client.get(f'/testmodel/archive/{self.obj1.date:%Y/%b/%d}/'),
             'DayArchiveView Test Template',
             status_code=200
         )
@@ -528,7 +498,7 @@ class GenericViewTests(TestCase):
 
     def test_datedetailview(self):
         self.assertContains(
-            self.client.get('/testmodel/archive/{0:%Y/%b/%d}/{1}'.format(self.obj1.date, self.obj1.pk)),
+            self.client.get(f'/testmodel/archive/{self.obj1.date:%Y/%b/%d}/{self.obj1.pk}'),
             'DateDetailView Test Template',
             status_code=200
         )
